<?php


class Csync extends Module
{
	private $_html = '';

	function __construct()
	{
		$this->name = 'Csync';
		$this->tab = 'Tools';
		$this->version = '0.1';

		parent::__construct();

		$this->displayName = 'Синхронизация с 1С';
		$this->description = 'Синхронизация товаров, цен и заказов с 1С';
		if (!Configuration::get('_PRICE_ID_')) $this->warning = 'Не установлен GUID набора цен';
		$this->confirmUninstall = 'Удаление модуля в дальнейшем сделает невозможным дифференциальную синхронизацию без проведения полной синхронизации';
	}

	public function install()
	{
		Db::getInstance()->Execute('ALTER TABLE `'._DB_PREFIX_.'category_group` DROP INDEX `category_group_index` , ADD UNIQUE `category_group_index` ( `id_category` , `id_group` )');
		Db::getInstance()->Execute('ALTER TABLE `'._DB_PREFIX_.'category_product` DROP INDEX `category_product_index` , ADD UNIQUE `category_product_index` ( `id_category` , `id_product` );');
		Db::getInstance()->Execute('ALTER TABLE `'._DB_PREFIX_.'category` ADD `xml` VARCHAR( 36 ) NOT NULL');
		Db::getInstance()->Execute('ALTER TABLE `'._DB_PREFIX_.'product` ADD `xml` VARCHAR( 36 ) NOT NULL');
		parent::install();
		return true;
	}

	public function uninstall()
	{
		Db::getInstance()->Execute('ALTER TABLE `'._DB_PREFIX_.'category`  DROP `xml`');
		Db::getInstance()->Execute('ALTER TABLE `'._DB_PREFIX_.'product`  DROP `xml`');
		if (!Configuration::deleteByName('_PRICE_ID_') OR !parent::uninstall())
			return false;
		return true;
	}
	
	private function _postProcess()
	{
		return 'Пока недоступно';
	}

	private function _displayForm()
	{
		$this->_html .=
			'<form action="'.$_SERVER['REQUEST_URI'].'" method="post">
				<fieldset class="space">
					<legend><img src="../img/admin/warning.gif" alt="" class="middle" />Выгрузка в 1С</legend>
					<input name="submitExport" class="button" type="submit" value="Выгрузить товары в 1С" />
				</fieldset>
			</form>';
	}
	private function _displayHelp()
	{
		$this->_html .='
			<form action="'.$_SERVER['REQUEST_URI'].'" method="post">
				<fieldset class="space">
					<legend><img src="../img/admin/cog.gif" alt="" class="middle" />Настройки</legend>
					<label>GUID набора цен</label>
					<div class="margin-form">
						<input type="text" name="price_id" value="'.Tools::getValue('price_id', Configuration::get('_PRICE_ID_')).'" />
						<p class="clear">Например 3800b1b1-c381-11dd-aa6f-993de20ae8cf</p>
					</div>
					<center><input type="submit" name="submitGUID" value="Обновить" class="button" /></center>
				</fieldset>
			</form>
			<fieldset class="space"><legend><img src="../img/admin/unknown.gif" alt="" class="middle" />Справка</legend><ol>
			<h3>Настройки 1С</h3>
			<li>Указать путь к скрипту <strong>http://'.htmlspecialchars($_SERVER['HTTP_HOST'], ENT_COMPAT, 'UTF-8').__PS_BASE_URI__.'modules/Csync/connect.php<strong></li>
			<li>Выполнить полную синхронизацию</li>
			<li>Настроить 1С на выполнение дифференциальной синхронизации</li>
			</ol><br />
			<h3>Особенности синхронизации</h3>
			<ul>
			<li>Авторизация по паролю не сделана (пока)</li>
			<li>При полной синхронизации выполняется очистка категорий, продуктов, папки с картинками</li>
			<li>При дифференциальной синхронизации производится обновление/добавление названий категорий, обновление/добавление названий товаров, картинок, изменяется родитель, rewrite_rule остается прежним</li>
			<li>При любой синхронизации проводится обновление цен и количества товара</li>
			<li>При перемещении товара между категориями в 1С в магазине из старой категории товар удален не будет (пока)</li>
			</ul></fieldset>
			<fieldset class="space"><legend><img src="../img/admin/warning.gif" alt="" class="middle" />Тестирование</legend><ol>
			<li>Проверка добавления товаров: <a href="http://'.htmlspecialchars($_SERVER['HTTP_HOST'], ENT_COMPAT, 'UTF-8').__PS_BASE_URI__.'modules/Csync/connect.php?type=catalog&mode=import&filename=import.xml"><strong>test</strong></a></li>
			<li>Проверка экспорта заказов: <a href="http://'.htmlspecialchars($_SERVER['HTTP_HOST'], ENT_COMPAT, 'UTF-8').__PS_BASE_URI__.'modules/Csync/connect.php?type=sale&mode=query"><strong>test</strong></a></li>
			</fieldset>
			';
	}
    
	function getContent()
	{
		$this->_html .= '<h2>Модуль синхронизации с 1C</h2>';
		if (Tools::isSubmit('submitExport'))
		{
			$this->_html .= '<div class="alert error">'.$this->_postProcess().'</div>';
		}
		if (Tools::isSubmit('submitGUID') AND ($guid = Tools::getValue('price_id')))
		{
			Configuration::updateValue('_PRICE_ID_', $guid);
			$this->_html .= '
			<div class="conf confirm">
				<img src="../img/admin/ok.gif" alt="" title="" />
				Настройки обновлены
			</div>';
		}
		$this->_displayHelp();
		$this->_displayForm();
		return $this->_html;
	}
}


?>
